@@ -19,7 +19,11 @@ from ase.units import Bohr, Hartree, Rydberg, fs
 from ase.data import chemical_symbols
 from ase.calculators.calculator import FileIOCalculator, Parameters, kpts2mp, ReadError
 
-from quantumespresso.io import *
+# Doubtful practice should be more selective in future
+from readers import *
+from writers import *
+from qeio import *
+from analyzers import *
 
 
 class QuantumEspresso(FileIOCalculator):
